'use-strict'

const {MongoClient } = require('mongodb');

let _url;
let _databaseName = null;
let _useUnifiedTopology = false;
let _useNewUrlParser = true;

let connectionInstance;
let db;

module.exports = {
	/**
	 * Pass values to local variables that will be used to create intance and connection
	 * @param {*} urlConnection 
	 * @param {*} dataBaseName 
	 * @param {*} useNewUrlParser 
	 * @param {*} unifiedTopology 
	 */
	initVars: (urlConnection, dataBaseName, useNewUrlParser, unifiedTopology) => {
		_url = urlConnection;
		_databaseName = dataBaseName;
		_useUnifiedTopology = unifiedTopology;
		_useNewUrlParser = useNewUrlParser;
	},
	/**
	 * Return a promise after try to connect and init database
	 * @returns Promise
	 */
	getInstance: () => {
		return new Promise(function (resolve, reject) {
			if (connectionInstance) {
				return resolve(connectionInstance);
			}

			MongoClient.connect(_url, {useNewUrlParser: _useNewUrlParser, useUnifiedTopology: _useUnifiedTopology }, function (err, client) {
				if (err) {
					return reject(err);
				}

				connectionInstance = client;
				db = client.db(_databaseName);

				return resolve(connectionInstance);
			});
		});
	},
	/**
	 * One connected use it get db instance to invoque db methods .find, .updateMany 
	 * @returns 
	 */
	getDb: () => {
		if (!db) {
			throw new Error("db object is not initialized!");
		}
		return db;
	}
};
